==> nextcloud-app-mail-0.6.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/cs_CZ.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Pošta",
    "Error while loading the accounts." : "Chyba při načítání účtů.",
    "Fetching Aliases Failed." : "Získávání aliasů se nezdařilo.",
    "Saving Aliases Failed." : "Ukládání aliasů se nezdařilo.",
    "Deleting Aliases Failed." : "Mazání aliasů se nezdařilo.",
    "Error while loading the selected account." : "Chyba během načítání vybraného účtu.",
    "Loading {folder}" : "Načítá se {folder}",
    "Searching for {query}" : "Hledání pro {query}",
    "Forwarded message" : "Přeposlaná zpráva",
    "Choose a folder to store the attachment in" : "Vyber adresář pro uložení přílohy",
    "Attachments saved to Files." : "Přílohy uloženy do Souborů.",
    "Attachment saved to Files." : "Příloha uložena do Souborů.",
    "Error while saving attachments to Files." : "Chyba při ukládání příloh do Souborů.",
    "Error while saving attachment to Files." : "Chyba při ukládání přílohy do Souborů.",
    "Message flag could not be set." : "Značka zpráva nemohla být nastavena.",
    "Invalid account" : "Neplatný účet",
    "Invalid folder" : "Neplatný adresář",
    "Unknown error" : "Neznámá chyba",
    "Error while creating an account: " : "Chyba při vytváření účtu:",
    "Could not load {tag}{name}{endtag}" : "Nelze načíst {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Nezdařilo se načtení {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Došlo k problému s načtením {tag}{name}{endtag}",
    "We couldn’t load your message" : "Nezdařilo se načtení vaší zprávy",
    "Unable to load the desired message" : "Nelze načíst vyžádanou zprávu",
    "There was a problem loading the message" : "Došlo k problému s načtením zprávy",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n nová zpráva v {folderName} \nod {from}","%n nové zprávy v {folderName} \nod {from}","%n nových zpráv v {folderName} \nod {from}"],
    "Show all folders" : "Zobrazit všechny adresáře",
    "Collapse folders" : "Sbalit adresáře",
    "Error while deleting account." : "Chyba při mazání účtu.",
    "Choose a file to add as attachment" : "Vyberte soubor k přiložení",
    "Reply" : "Odpověď",
    "Send" : "Odeslat",
    "Sending …" : "Odesílám ...",
    "Message sent!" : "Zpráva odeslána!",
    "Server error" : "Chyba serveru",
    "An unknown error occurred" : "Nastala neznámá chyba",
    "Opening HTML drafts is not supported yet." : "Otevírání HTML konceptů ještě není podporováno.",
    "Draft saved!" : "Koncept uložen!",
    "you" : "vy",
    "Send message to {email}" : "Poslat email na {email}",
    "No writable calendars found" : "Nebyly nalezeny žádné zapisovatelné kalendáře",
    "Error while importing the calendar event" : "Chyba při importu události kalendáře",
    "Error while downloading calendar event" : "Chyba při stahování události kalendáře",
    "Error while deleting message." : "Chyba při mazání zprávy.",
    "Error while loading messages." : "Chyba během načítání zpráv.",
    "Connecting" : "Připojování",
    "Connect" : "Připojit",
    "Inbox" : "Doručená",
    "Sent" : "Odeslaná",
    "Drafts" : "Koncepty",
    "Archive" : "Archiv",
    "Trash" : "Koš",
    "Junk" : "Spam",
    "All" : "Vše",
    "Favorites" : "Oblíbené",
    "Creating account failed: " : "Vytvoření účtu selhalo:",
    "Auto detect failed. Please use manual mode." : "Autodetekce selhala. Použijte prosím ruční nastavení.",
    "Delete permanently" : "Trvale odstranit",
    "& others" : "a další",
    "All inboxes" : "Všechny schránky",
    "Error loading message" : "Chyba načtení zprávy",
    "Forwarding to %s" : "Přeposílá na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikněte zde, pokud nebudete automaticky přesměrováni během příštích několika vteřin.",
    "Redirect" : "Přesměrovat",
    "The link leads to %s" : "Odkaz vede na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Pokud nechcete tuto stránku navštívit, můžete se vrátit do <a href=\"%s\">emailu</a>.",
    "Continue to %s" : "Pokračovat na %s",
    "Settings" : "Nastavení",
    "Delete account" : "Smazat účet",
    "Account Settings" : "Nastavení účtu",
    "Aliases" : "Aliasy",
    "Mail address" : "Emailová adresa",
    "Display Name" : "Zobrazované jméno",
    "Save" : "Uložit",
    "Add attachment from Files" : "Přidat přílohu ze Souborů",
    "from" : "od",
    "to" : "komu",
    "cc" : "kopie",
    "bcc" : "skrytá kopie",
    "Subject" : "Předmět",
    "Import into calendar" : "Importovat do kalendáře",
    "Download attachment" : "Stáhnout přílohu",
    "Save to Files" : "Uložit do Souborů",
    "Save all to Files" : "Uložit vše do Souborů",
    "The images have been blocked to protect your privacy." : "Obrázky byly zablokovány pro ochranu vašeho soukromí.",
    "Show images from this sender" : "Zobrazit obrázky od tohoto odesílatele",
    "Forward" : "Přeposlat",
    "New message" : "Nová zpráva",
    "No search results for" : "Nic nenalezeno pro",
    "Add mail account" : "Přidat emailový účet",
    "Connect your mail account" : "Připojit emailový účet",
    "Name" : "Jméno",
    "Mail Address" : "Emailová adresa",
    "Password" : "Heslo",
    "Manual configuration" : "Manuální nastavení",
    "IMAP Host" : "IMAP hostitel",
    "IMAP security" : "IMAP zabezpečení",
    "None" : "Žádné",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP uživatel",
    "IMAP Password" : "IMAP heslo",
    "SMTP Host" : "SMTP hostitel",
    "SMTP security" : "SMTP zabezpečení",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP uživatel",
    "SMTP Password" : "SMTP heslo"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-app-mail-0.7.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/cs_CZ.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Pošta",
    "Error while loading the accounts." : "Chyba při načítání účtů.",
    "Error while loading the selected account." : "Chyba během načítání vybraného účtu.",
    "Can not load this folder." : "Tuto složku nelze načíst.",
    "Loading {folder}" : "Načítá se {folder}",
    "Searching for {query}" : "Hledání pro {query}",
    "Forwarded message" : "Přeposlaná zpráva",
    "Choose a folder to store the attachment in" : "Vyber adresář pro uložení přílohy",
    "Attachments saved to Files." : "Přílohy uloženy do Souborů.",
    "Attachment saved to Files." : "Příloha uložena do Souborů.",
    "Error while saving attachments to Files." : "Chyba při ukládání příloh do Souborů.",
    "Error while saving attachment to Files." : "Chyba při ukládání přílohy do Souborů.",
    "Message flag could not be set." : "Značka zpráva nemohla být nastavena.",
    "Could not move message." : "Nelze přesunout zprávu.",
    "Invalid account" : "Neplatný účet",
    "Invalid folder" : "Neplatný adresář",
    "Unknown error" : "Neznámá chyba",
    "Error while creating the account: " : "Chyba při vytváření účtu:",
    "All inboxes" : "Všechny schránky",
    "Could not load {tag}{name}{endtag}" : "Nelze načíst {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Nezdařilo se načtení {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Došlo k problému s načtením {tag}{name}{endtag}",
    "We couldn’t load your message" : "Nezdařilo se načtení vaší zprávy",
    "Unable to load the desired message" : "Nelze načíst vyžádanou zprávu",
    "There was a problem loading the message" : "Došlo k problému s načtením zprávy",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n nová zpráva v {folderName} \nod {from}","%n nové zprávy v {folderName} \nod {from}","%n nových zpráv v {folderName} \nod {from}"],
    "Show all folders" : "Zobrazit všechny adresáře",
    "Collapse folders" : "Sbalit adresáře",
    "Error while deleting account." : "Chyba při mazání účtu.",
    "Choose a file to add as attachment" : "Vyberte soubor k přiložení",
    "Reply" : "Odpověď",
    "Send" : "Odeslat",
    "Sending …" : "Odesílám ...",
    "Message sent!" : "Zpráva odeslána!",
    "Server error" : "Chyba serveru",
    "An unknown error occurred" : "Nastala neznámá chyba",
    "Opening HTML drafts is not supported yet." : "Otevírání HTML konceptů ještě není podporováno.",
    "Draft saved!" : "Koncept uložen!",
    "you" : "vy",
    "Send message to {email}" : "Poslat email na {email}",
    "No writable calendars found" : "Nebyly nalezeny žádné zapisovatelné kalendáře",
    "Error while importing the calendar event" : "Chyba při importu události kalendáře",
    "Error while downloading calendar event" : "Chyba při stahování události kalendáře",
    "Error while deleting message." : "Chyba při mazání zprávy.",
    "Error while loading messages." : "Chyba během načítání zpráv.",
    "Setting up your account" : "Nastavení účtu",
    "Inbox" : "Doručená",
    "Sent" : "Odeslaná",
    "Drafts" : "Koncepty",
    "Archive" : "Archiv",
    "Trash" : "Koš",
    "Junk" : "Spam",
    "All" : "Vše",
    "Favorites" : "Oblíbené",
    "Creating account failed: " : "Vytvoření účtu selhalo:",
    "Auto detect failed. Please use manual mode." : "Autodetekce selhala. Použijte prosím ruční nastavení.",
    "Delete permanently" : "Trvale odstranit",
    "& others" : "a další",
    "Error loading message" : "Chyba načtení zprávy",
    "Settings" : "Nastavení",
    "Forwarding to %s" : "Přeposílá na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikněte zde, pokud nebudete automaticky přesměrováni během příštích několika vteřin.",
    "Redirect" : "Přesměrovat",
    "The link leads to %s" : "Odkaz vede na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Pokud nechcete tuto stránku navštívit, můžete se vrátit do <a href=\"%s\">emailu</a>.",
    "Continue to %s" : "Pokračovat na %s",
    "Delete account" : "Smazat účet",
    "Try again" : "Zkusit znovu",
    "New message" : "Nová zpráva",
    "Account Settings" : "Nastavení účtu",
    "Aliases" : "Aliasy",
    "Mail address" : "Emailová adresa",
    "Display Name" : "Zobrazované jméno",
    "Save" : "Uložit",
    "Keyboard shortcuts" : "Klávesové zkratky",
    "Speed up your Mail experience with these quick shortcuts." : "Urychlete svůj Mail pomocí těchto rychlých zkratek.",
    "Newer message" : "Novější zpráva",
    "Older message" : "Starší zpráva",
    "Toggle star" : "Přepnout hvězdu",
    "Toggle unread" : "Přepnout nepřečtené",
    "Delete" : "Smazat",
    "Search" : "Hledat",
    "Refresh" : "Obnovit",
    "Connect your mail account" : "Připojit emailový účet",
    "Name" : "Jméno",
    "Mail Address" : "Emailová adresa",
    "Password" : "Heslo",
    "Manual configuration" : "Manuální nastavení",
    "IMAP Host" : "IMAP hostitel",
    "IMAP security" : "IMAP zabezpečení",
    "None" : "Žádné",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP uživatel",
    "IMAP Password" : "IMAP heslo",
    "SMTP Host" : "SMTP hostitel",
    "SMTP security" : "SMTP zabezpečení",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP uživatel",
    "SMTP Password" : "SMTP heslo",
    "Connect" : "Připojit",
    "from" : "od",
    "to" : "komu",
    "cc" : "kopie",
    "bcc" : "skrytá kopie",
    "Subject" : "Předmět",
    "Save all to Files" : "Uložit vše do Souborů",
    "Add mail account" : "Přidat emailový účet",
    "No search results for" : "Nic nenalezeno pro",
    "The images have been blocked to protect your privacy." : "Obrázky byly zablokovány pro ochranu vašeho soukromí.",
    "Show images from this sender" : "Zobrazit obrázky od tohoto odesílatele",
    "Forward" : "Přeposlat",
    "Import into calendar" : "Importovat do kalendáře",
    "Download attachment" : "Stáhnout přílohu",
    "Save to Files" : "Uložit do Souborů"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
